@@ -23,10 +23,10 @@ from werkzeug.serving import run_with_reloader
 from .namespace import Namespace
 from .test_client import SocketIOTestClient
 
-__version__ = '3.0.0'
+__version__ = '3.1.2'
 
 
-class _SocketIOMiddleware(socketio.Middleware):
+class _SocketIOMiddleware(socketio.WSGIApp):
     """This WSGI middleware simply exposes the Flask application in the WSGI
     environment before executing the request.
     """
@@ -34,7 +34,7 @@ class _SocketIOMiddleware(socketio.Middleware):
         self.flask_app = flask_app
         super(_SocketIOMiddleware, self).__init__(socketio_app,
                                                   flask_app.wsgi_app,
-                                                  socketio_path)
+                                                  socketio_path=socketio_path)
 
     def __call__(self, environ, start_response):
         environ = environ.copy()
